@@ -1,13 +1,17 @@
 import uuid
+from typing import Optional
 
 from graphviz import Digraph
+from mixins import EqOnAttrsMixin, EqHashMixin
 
 from datacode.graph.base import GraphObject
 
 
-class Node(GraphObject):
+class Node(GraphObject, EqHashMixin, EqOnAttrsMixin):
+    _recursive_hash_convert = True
+    equal_attrs = ['label', 'name', 'id', 'node_kwargs']
 
-    def __init__(self, name, label='name', **node_kwargs):
+    def __init__(self, name: str, label: str = 'name', id_: Optional[str] = None, **node_kwargs):
         if label == 'name':
             self.label = name
         elif label is None:
@@ -16,7 +20,10 @@ class Node(GraphObject):
             self.label = label
 
         self.name = name
-        self.id = str(uuid.uuid1())
+        if id_ is None:
+            self.id = str(uuid.uuid4())
+        else:
+            self.id = id_
         self.node_kwargs = node_kwargs
 
     def add_to_graph(self, graph: Digraph):
