@@ -73,6 +73,11 @@ class DataSource(LinkedItem, Graphable, ReprMixin):
         if columns is not None and not isinstance(columns, list):
             columns = list(columns)
 
+        # In case columns are shared between sources, don't modify the
+        # existing columns. Copy the passed columns
+        if columns is not None:
+            columns = [col.copy() for col in columns]
+
         # Handle setup for loading columns needed only for calculations
         extra_cols_for_calcs = []
         extra_vars_for_calcs = []
@@ -317,6 +322,7 @@ class DataSource(LinkedItem, Graphable, ReprMixin):
             detached_attrs = self._detach_attrs(keep_refs)
         if not kwargs:
             obj = deepcopy(self)
+            self.update(detached_attrs)
             obj.update(detached_attrs)
             obj.refresh_columns_series()
             return obj
@@ -332,7 +338,9 @@ class DataSource(LinkedItem, Graphable, ReprMixin):
         klass = type(self)
         obj = klass(**config_dict)
         obj.update(detached_attrs)
+        self.update(detached_attrs)
         obj.refresh_columns_series()
+        self.refresh_columns_series()
         return obj
 
     def _detach_attr(self, attr: str) -> Any:
